@@ -332,10 +332,3 @@ PCSC_API LONG SCardSetAttrib(SCARDHANDLE hCard,
 	return redirect.SCardSetAttrib(hCard, dwAttrId, pbAttr, cbAttrLen);
 }
 
-/** Protocol Control Information for T=0 */
-PCSC_API const SCARD_IO_REQUEST g_rgSCardT0Pci = { SCARD_PROTOCOL_T0, sizeof(SCARD_IO_REQUEST) };
-/** Protocol Control Information for T=1 */
-PCSC_API const SCARD_IO_REQUEST g_rgSCardT1Pci = { SCARD_PROTOCOL_T1, sizeof(SCARD_IO_REQUEST) };
-/** Protocol Control Information for raw access */
-PCSC_API const SCARD_IO_REQUEST g_rgSCardRawPci = { SCARD_PROTOCOL_RAW, sizeof(SCARD_IO_REQUEST) };
-
